@@ -1,7 +1,7 @@
 use strict;
 BEGIN{ if (not $] < 5.006) { require warnings; warnings->import } }
 package Test::Reporter::Transport;
-our $VERSION = '1.59'; # VERSION
+our $VERSION = '1.60'; # VERSION
 
 sub new     { die "Not implemented" }
 
@@ -15,7 +15,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -23,7 +23,7 @@ Test::Reporter::Transport - base class for Test::Reporter transports
 
 =head1 VERSION
 
-version 1.59
+version 1.60
 
 =head1 SYNOPSIS
 
@@ -121,10 +121,6 @@ Kurt Starsinic <Kurt.Starsinic@isinet.com>
 
 =back
 
-=head1 CONTRIBUTOR
-
-Vincent Pit <perl@profvince.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Authors and Contributors.
